summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristophe Lyon <christophe.lyon@linaro.org>2018-11-30 15:38:19 +0000
committerChristophe Lyon <christophe.lyon@linaro.org>2018-11-30 15:38:19 +0000
commit924cce4360a9038e5740aba48b29d5b50783e628 (patch)
tree7ba9faf91416ab0e7795ef5a659b78079c5ad2ed
parent300378363a38eb19ccb8aaf764fe0702e9aa244d (diff)
compare_dg_tests.pl: Replace "minor" with "improvements"
Change-Id: I3787fcb314706648465211c60fff6a9d708c24e6
-rwxr-xr-xcompare_dg_tests.pl6
-rw-r--r--testsuite/expected-1-2-long.txt4
-rw-r--r--testsuite/expected-1-2.txt4
3 files changed, 7 insertions, 7 deletions
diff --git a/testsuite/expected-1-2-long.txt b/testsuite/expected-1-2-long.txt
index 217aabb..26ea15c 100644
--- a/testsuite/expected-1-2-long.txt
+++ b/testsuite/expected-1-2-long.txt
@@ -175,7 +175,7 @@ o REGRESSIONS:
-o MINOR TO BE CHECKED:
+o IMPROVEMENTS TO BE CHECKED:
+------------------------------------------+---------+
| PASS disappears [PASS => ] | 1 |
| PASS now XFAIL [PASS =>XFAIL] | 2 |
@@ -217,7 +217,7 @@ o MINOR TO BE CHECKED:
| ERROR disappears [ERROR=> ] | 1 |
| HW dependent cases [HW-DEPENDENT] | 2 |
+------------------------------------------+---------+
- | TOTAL_MINOR_TO_BE_CHECKED | 41 |
+ | TOTAL_IMPROVEMENTS_TO_BE_CHECKED | 41 |
+------------------------------------------+---------+
- PASS disappears [PASS => ]:
diff --git a/testsuite/expected-1-2.txt b/testsuite/expected-1-2.txt
index 3e6ac73..695bde2 100644
--- a/testsuite/expected-1-2.txt
+++ b/testsuite/expected-1-2.txt
@@ -49,7 +49,7 @@ o REGRESSIONS:
+------------------------------------------+---------+
-o MINOR TO BE CHECKED:
+o IMPROVEMENTS TO BE CHECKED:
+------------------------------------------+---------+
| PASS disappears [PASS => ] | 1 |
| PASS now XFAIL [PASS =>XFAIL] | 2 |
@@ -91,7 +91,7 @@ o MINOR TO BE CHECKED:
| ERROR disappears [ERROR=> ] | 1 |
| HW dependent cases [HW-DEPENDENT] | 2 |
+------------------------------------------+---------+
- | TOTAL_MINOR_TO_BE_CHECKED | 41 |
+ | TOTAL_IMPROVEMENTS_TO_BE_CHECKED | 41 |
+------------------------------------------+---------+
diff --git a/compare_dg_tests.pl b/compare_dg_tests.pl
index 35245b1..388db89 100755
--- a/compare_dg_tests.pl
+++ b/compare_dg_tests.pl
@@ -752,7 +752,7 @@ sub print_compare_results_summary($$)
printf "$col_reset\n";
}
#### MINOR TO BE CHECKED ?
if (not $quiet and not $short)
{
$total_better =
@@ -796,7 +796,7 @@ sub print_compare_results_summary($$)
scalar(@{$res->{$ERROR_DISAPPEARS}})+
scalar(@{$res->{$UNHANDLED_CASES}});
- printf "$col_pink"."o MINOR TO BE CHECKED:\n";
+ printf "$col_pink"."o IMPROVEMENTS TO BE CHECKED:\n";
printf " +------------------------------------------+---------+\n";
printf " | %-40s | %7d |\n", $PASS_DISAPPEARS, scalar(@{$res->{$PASS_DISAPPEARS}}) if (scalar(@{$res->{$PASS_DISAPPEARS}}));
printf " | %-40s | %7d |\n", $PASS_XFAIL, scalar(@{$res->{$PASS_XFAIL}}) if (scalar(@{$res->{$PASS_XFAIL}}));
@@ -840,7 +840,7 @@ sub print_compare_results_summary($$)
printf " | %-40s | %7d |\n", $UNSTABLE_CASES, scalar(@{$res->{$UNSTABLE_CASES}}) if (scalar(@{$res->{$UNSTABLE_CASES}}));
printf " | %-40s | %7d |\n", $HWDEP_CASES, scalar(@{$res->{$HWDEP_CASES}}) if (scalar(@{$res->{$HWDEP_CASES}}));
printf " +------------------------------------------+---------+\n";
- printf " | %-40s | %7d |\n", "TOTAL_MINOR_TO_BE_CHECKED", $total_better + scalar(@{$res->{$UNSTABLE_CASES}});;
+ printf " | %-40s | %7d |\n", "TOTAL_IMPROVEMENTS_TO_BE_CHECKED", $total_better + scalar(@{$res->{$UNSTABLE_CASES}});;
printf " +------------------------------------------+---------+\n";
printf "\n";
@@ -752,7 +752,7 @@ sub print_compare_results_summary($$)
printf "$col_reset\n";
}
- #### MINOR TO BE CHECKED ?
+ #### IMPROVEMENTS TO BE CHECKED ?
if (not $quiet and not $short)
{